@@ -36,6 +36,9 @@ class App():
         self.is_app_running = False
 
 
-if __name__ == "__main__":
+def main():
     app = App()
     app.run()
+
+if __name__ == "__main__":
+    main()    
\ No newline at end of file
